@@ -3,7 +3,7 @@
 ##########################################################################
 # OpenLP - Open Source Lyrics Projection                                 #
 # ---------------------------------------------------------------------- #
-# Copyright (c) 2008-2023 OpenLP Developers                              #
+# Copyright (c) 2008-2024 OpenLP Developers                              #
 # ---------------------------------------------------------------------- #
 # This program is free software: you can redistribute it and/or modify   #
 # it under the terms of the GNU General Public License as published by   #
@@ -108,6 +108,9 @@ class ServiceTab(SettingsTab):
         self.auto_preview_check_box = QtWidgets.QCheckBox(self.slide_controller_groupbox)
         self.auto_preview_check_box.setObjectName('auto_preview_check_box')
         self.slide_controller_layout.addRow(self.auto_preview_check_box)
+        self.live_preview_shows_blank_screen_check_box = QtWidgets.QCheckBox(self.slide_controller_groupbox)
+        self.live_preview_shows_blank_screen_check_box.setObjectName('live_preview_shows_blank_screen_check_box')
+        self.slide_controller_layout.addRow(self.live_preview_shows_blank_screen_check_box)
         self.timeout_label = QtWidgets.QLabel(self.slide_controller_groupbox)
         self.timeout_label.setObjectName('timeout_label')
         self.timeout_spin_box = QtWidgets.QSpinBox(self.slide_controller_groupbox)
@@ -190,6 +193,7 @@ class ServiceTab(SettingsTab):
                                                                            'items to Live'))
         self.auto_preview_check_box.setText(translate('OpenLP.ServiceTab',
                                                       'Automatically preview the next item in service'))
+        self.live_preview_shows_blank_screen_check_box.setText(UiStrings().LivePreviewShowsBlankScreen)
         self.timeout_label.setText(translate('OpenLP.ServiceTab', 'Timed slide interval:'))
         self.timeout_spin_box.setSuffix(translate('OpenLP.ServiceTab', ' sec'))
         # Service Item Wrapping
@@ -220,6 +224,9 @@ class ServiceTab(SettingsTab):
         self.auto_unblank_check_box.setChecked(self.settings.value('core/auto unblank'))
         self.click_live_slide_to_unblank_check_box.setChecked(self.settings.value('core/click live slide to unblank'))
         self.auto_preview_check_box.setChecked(self.settings.value('core/auto preview'))
+        self.live_preview_shows_blank_screen_check_box.setChecked(
+            self.settings.value('core/live preview shows blank screen')
+        )
         self.timeout_spin_box.setValue(self.settings.value('core/loop delay'))
         # Service Item Wrapping
         self.slide_limits = self.settings.value('advanced/slide limits')
@@ -253,6 +260,12 @@ class ServiceTab(SettingsTab):
         self.settings.setValue('core/click live slide to unblank',
                                self.click_live_slide_to_unblank_check_box.isChecked())
         self.settings.setValue('core/auto preview', self.auto_preview_check_box.isChecked())
+        live_preview_shows_blank_screen_check_box_is_checked = \
+            self.live_preview_shows_blank_screen_check_box.isChecked()
+        self.settings.setValue('core/live preview shows blank screen',
+                               live_preview_shows_blank_screen_check_box_is_checked)
+        if not live_preview_shows_blank_screen_check_box_is_checked:
+            self.settings_form.register_post_process('slidecontroller_preview_display_show_display')
         self.settings.setValue('core/loop delay', self.timeout_spin_box.value())
         # Service Item Wrapping
         self.settings.setValue('advanced/slide limits', self.slide_limits)
