@@ -3,7 +3,7 @@
 ##########################################################################
 # OpenLP - Open Source Lyrics Projection                                 #
 # ---------------------------------------------------------------------- #
-# Copyright (c) 2008-2023 OpenLP Developers                              #
+# Copyright (c) 2008-2024 OpenLP Developers                              #
 # ---------------------------------------------------------------------- #
 # This program is free software: you can redistribute it and/or modify   #
 # it under the terms of the GNU General Public License as published by   #
@@ -108,6 +108,10 @@ class MediaMediaItem(FolderLibraryItem):
             self.can_add_to_service = False
         if State().check_preconditions('media_live'):
             self.can_make_live = True
+        else:
+            self.can_preview = False
+            self.can_make_live = False
+            self.can_add_to_service = False
 
     def initialise(self):
         """
@@ -172,7 +176,7 @@ class MediaMediaItem(FolderLibraryItem):
             self.load_menu.addAction(self.open_network_stream)
             self.toolbar.actions['mediaLoadAction'].setMenu(self.load_menu)
             button = self.toolbar.widgetForAction(self.toolbar.actions['mediaLoadAction'])
-            button.setPopupMode(QtWidgets.QToolButton.MenuButtonPopup)
+            button.setPopupMode(QtWidgets.QToolButton.ToolButtonPopupMode.MenuButtonPopup)
 
     def generate_slide_data(self, service_item, *, item=None, remote=False, context=ServiceItemContext.Service,
                             **kwargs):
@@ -238,8 +242,6 @@ class MediaMediaItem(FolderLibraryItem):
         service_item.add_capability(ItemCapabilities.CanAutoStartForLive)
         service_item.add_capability(ItemCapabilities.CanEditTitle)
         service_item.add_capability(ItemCapabilities.RequiresMedia)
-        if self.settings.value('media/media auto start') == QtCore.Qt.Checked:
-            service_item.will_auto_start = True
         # force a non-existent theme
         service_item.theme = -1
         # validate the item after all capabilities has been added
